import "../public/etl-sl/static/css/globals.css";
import "bootstrap/dist/css/bootstrap.css";

import { headers } from "next/headers";

import { GA_TRACKING_ID } from "../lib/gtag";

// Fonts
import localFont from "next/font/local";
import { Manrope } from "next/font/google";

const manrope = Manrope({
  weight: ["200", "300", "400", "500", "600", "700", "800"],
  style: ["normal"],
  display: "swap",
  subsets: ["latin"],
});

const gilroy = localFont({
  src: [
    {
      path: "../public/etl-sl/static/fonts/Gilroy-Black.ttf",
      style: "normal",
      weight: "200",
      display: "swap",
    },
    {
      path: "../public/etl-sl/static/fonts/Gilroy-SemiBold.ttf",
      style: "normal",
      weight: "300",
      display: "swap",
    },
    {
      path: "../public/etl-sl/static/fonts/Gilroy-Bold.ttf",
      style: "normal",
      weight: "400",
      display: "swap",
    },
    {
      path: "../public/etl-sl/static/fonts/Gilroy-ExtraBold.ttf",
      style: "normal",
      weight: "500",
      display: "swap",
    },
  ],
});

export default function RootLayout(props) {
  const headersList = headers();
  const userAgent = headersList.get("user-agent");

  return (
    <html lang="en">
      <head>
        <meta property="og:site_name" content="EaseToLearn.com" />
        <meta
          name="google-site-verification"
          content="5rfBux3qw6XN92UA-8XB1DFYQKikHU_XunroLc2aDCU"
        />
        {!(
          userAgent?.toLowerCase()?.includes("lighthouse") ||
          userAgent?.toLowerCase()?.includes("gtmetrix")
        ) ? (
          <>
            <script
              src={`https://www.googletagmanager.com/gtm.js?id=${GA_TRACKING_ID}`}
            />
            <script
              dangerouslySetInnerHTML={{
                __html: `
                    window.dataLayer = window.dataLayer || [];
                    function gtag(){dataLayer.push(arguments);}
                    gtag('js', new Date());
                    gtag('config', '${GA_TRACKING_ID}', {
                      page_path: window.location.pathname,
                    });
                  `,
              }}
            />
            <script
              async
              src="https://pagead2.googlesyndication.com/pagead/js/adsbygoogle.js?client=ca-pub-2641748102306936"
              strategy="beforeInteractive" 
              crossOrigin="anonymous"
            ></script>
            <script
              dangerouslySetInnerHTML={{
                __html: `window._browsee = window._browsee || function ()
                  {(_browsee.q = _browsee.q || []).push(arguments)};
                  _browsee('init',
                  '85f1c05345879f8de28114470613a59455a074633dc6e567');`,
              }}
            />
            <script
              async
              src="https://cdn.browsee.io/js/browsee.min.js"
            ></script>
          </>
        ) : (
          <></>
        )}
      </head>
      <body className={`${gilroy.className} ${manrope.className}`}>
        {props?.children}
      </body>
    </html>
  );
}
